function tikz_plot_for_paper
% Mahmood Amintoosi
masir = 'D:\work\Presentations\XePersian\STTU\Samples\paper\';

clear options

x = -4*pi:.1:4*pi;

fun{1}.f = inline('x.*sin(x)');
fun{1}.name = '$x sin(x)$';

fun{2}.f = inline('sin(x)');%(rand(1,1:length(x))-.5)*3
fun{2}.name = '$9 sin(x)$';

methods = [];
options.x=x;
% methods
for fn=1:length(fun)
    methods{fn}.y = fun{fn}.f(x);
    methods{fn}.name = fun{fn}.name;
end
% 
% options.axisType = 'semilogyaxis';
% options.xLabel = 'Image Number';
% options.step = 4;
% fieldName = 'recLocErrors';
% writeTikzPlot(recCompareFileName,masir,fieldName,options);
% 
% fieldName = 'recParamErrors';
% writeTikzPlot(recCompareFileName,masir,fieldName,options);
% 
options.axisType = 'axis';%'semilogyaxis';%
options.step = 10;
options.load_xTickLabels = 2; % 1:use DB names as XTickLabel, 2: ... ,3: ..
options.rotation = 70; 

%options.yLabel=ctitles{cNo};
writeTikzPlot(methods,masir,options);

options.step = 20;
printTable(methods,options);

pause(.5);
system(['xelatex ' masir 'articlePlots.tex']);
% pause(5);
% system(['texworks.exe ' masir 'articlePlots.pdf']);

end
%%
function writeTikzPlot(methods,masir,options)
if ~isfield(options,'load_xTickLabels');
    options.load_xTickLabels = 0;
end
if ~isfield(options,'rotation');
    options.rotation = 0;
end
if ~isfield(options,'axisType');
    options.axisType = 'axis';
end
if ~isfield(options,'xLabel');
    options.xLabel = '';
end
if ~isfield(options,'yLabel');
    options.yLabel = 'Error';
end
if ~isfield(options,'step');
    options.step = 1;
end
if ~isfield(options,'appendix');
    options.appendix = '';
end
if ~isfield(options,'minormax');
    options.minormax = 'min';
end

fieldName = 'y';
fileName = [fieldName options.appendix];

% Writing Data
    dataFileName = [fileName  'Data.txt'];
    fid = fopen([masir dataFileName],'wt');
    fprintf(fid,'dbNo \t');
    mNo=0;
    mList =[];
    % maxY = -1e30;
    for i=1:length(methods)
        mNo=mNo+1;
        fprintf(fid,'m%d \t',mNo);
        mList = [mList sprintf(',(methods{%d}.y(i))',i)];
    end
    fprintf(fid,'\n');

    formatStr = repmat('%d ',1,mNo);
    formatStr = ['%d ' formatStr '\n'];
    
    nRow =length(options.x);
    for i=1:nRow
        str = ['fprintf(fid,''' formatStr ''',i' , mList ');'];
        eval(str);
    end
    fclose(fid);
    % Computing the best mean score
    for i=1:length(methods)
        if isempty(methods{i}), continue, end;
        str = sprintf('mean(methods{i}.%s);',fieldName);
        meanValue = eval(str);
    end
    
    % Writing Tikz
    legendStr = '';
    for i=1:length(methods)
        if isempty(methods{i}), continue, end;
        str = sprintf('mean(methods{i}.%s);',fieldName);
        meanValue = eval(str);
        methodName = methods{i}.name;
        legendStr = [legendStr,sprintf('%s (Mean=%5.2f),',methodName,meanValue)];
    end
    legendStr(end) = ' ';

    tikzFileName = [masir fileName '.tikz'];
    fid_tex = fopen(tikzFileName,'wt');
    fprintf(fid_tex,'\\centering\n');
    fprintf(fid_tex,'\\pgfplotstableread{%s}{\\table}\n',dataFileName);
    fprintf(fid_tex,'\\begin{tikzpicture}[scale=.85]\n');
    fprintf(fid_tex,'\\pgfplotsset{every axis legend/.append style={at={(.3,1.15)},anchor=west}}\n');
    fprintf(fid_tex,'\\begin{%s}[cycle list name=mylist,legend columns=1, \n width=1\\textwidth, height=6cm,\n',options.axisType);
    fprintf(fid_tex,'xtick={');
    i=1;
    for dbNo=1:options.step:nRow
        fprintf(fid_tex,'%d',dbNo);
        if i~=length(1:options.step:nRow)
            fprintf(fid_tex,',');
        end
        i = i+1;
    end
	 fprintf(fid_tex,'},\n');
	 
     switch options.load_xTickLabels
         case 1
             fprintf(fid_tex,'xticklabels={');
             for dbNo=1:nRow
                 db_name = options.names{dbNo};
                 if any(db_name=='_')
                     idx = find(db_name=='_');
                     db_name(idx)=' ';   
                 end
                 fprintf(fid_tex,'%s',db_name);
                 if dbNo~=nRow
                     fprintf(fid_tex,',');
                 end
             end
             fprintf(fid_tex,'},\n');
             fprintf(fid_tex,' x tick label style={rotate=%d,anchor=east}, ',options.rotation);
         case 2
             fprintf(fid_tex,'xticklabels={');
             fprintf(fid_tex,'%4.2f,',options.x(1:options.step:end));
             fprintf(fid_tex,'},\n');
             fprintf(fid_tex,' x tick label style={rotate=%d,anchor=east}, ',options.rotation);
         otherwise
             fprintf(fid_tex,' x tick label style={rotate=%d}, ',options.rotation);
     end
     fprintf(fid_tex,' ylabel=%s, xlabel=%s]\n',options.yLabel,options.xLabel);

    for i=1:mNo
        fprintf(fid_tex,'\\addplot table[x=dbNo,y=m%d] from \\table;\n',i);
    end
    fprintf(fid_tex,'\\legend{%s}\n',legendStr);
    fprintf(fid_tex,'\\end{%s}\n',options.axisType);
    fprintf(fid_tex,'\\end{tikzpicture}\n');
    fclose(fid_tex);
    disp(['Done ' datestr(now)])
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% printTable
function printTable(methods,options)
tableFileName = 'yTable.tex';
fid = fopen(tableFileName,'wt');
fprintf(fid,'\\begin{table}\n');
fprintf(fid,'\\centering\n');
fprintf(fid,'\\begin{tabular}{|c|c|');
for m=1:length(methods)
    fprintf(fid,'c|');
end
fprintf(fid,'}\n\\hline\n');
% \hhline{|=====|}
fprintf(fid,' Row & X ');
for m=1:length(methods)
    fprintf(fid,'& %s ',methods{m}.name);
end
fprintf(fid,'\\\\ \n');
fprintf(fid,'\\hhline{|====|}\n');

for dbNo = 1:options.step:length(options.x)
    fprintf(fid,'%d & %4.2f ',dbNo,options.x(dbNo));
    
    for m=1:length(methods)
        fprintf(fid,'& %5.2f ',methods{m}.y(dbNo));
    end
    fprintf(fid,'\\\\ \n');
end
fprintf(fid,'\n\\hline\n');
fprintf(fid,'\\end{tabular} \n');
fprintf(fid,'\\caption{%s}\n\\end{table}\n','Error Table');
fclose(fid);
end %end of printTable
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%